| Stability | experimental |
|---|---|
| Maintainer | Ertugrul Soeylemez <es@ertes.de> |
Control.ContStuff.MonadsTf
Description
This module provides contstuff class instances for the monads from the monads-tf package. This makes using both transformer libraries in a single project much more convenient.